/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this file,
 * You can obtain one at http://mozilla.org/MPL/2.0/. */

body {
  font-family: Helvetica, Arial, sans-serif;
  font-size: 12px;
  min-width: 1200px;
  color: #999;
}
h2 {
  font-size: 16px;
  color: black;
}

p {
  color: black;
}

a {
  color: #999;
}

table {
  border-collapse: collapse;
}

/******************************
 * SUMMARY INFORMATION
 ******************************/

#environment td {
  padding: 5px;
  border: 1px solid #e6e6e6;
}

#environment tr:nth-child(odd) {
  background-color: #f6f6f6;
}

/******************************
 * TEST RESULT COLORS
 ******************************/
span.pass,
.pass .col-result {
  color: green;
}
span.expected_fail,
.expected_fail .col-result,
span.expected_skip,
.expected_skip .col-result,
span.skip,
.skip .col-result,
span.known_intermittent,
.known_intermittent .col-result {
  color: orange;
}
span.error,
.error .col-result,
span.fail,
.fail .col-result,
span.unexpected_error,
.unexpected_error .col-result,
span.unexpected_fail,
.unexpected_fail .col-result,
span.unexpected_pass,
.unexpected_pass .col-result {
  color: red;
}

/******************************
 * RESULTS TABLE
 *
 * 1. Table Layout
 * 2. Debug
 * 3. Sorting items
 *
 ******************************/

/*------------------
 * 1. Table Layout
 *------------------*/

#results-table {
  border: 1px solid #e6e6e6;
  color: #999;
  font-size: 12px;
  width: 100%;
}

#results-table th,
#results-table td {
  padding: 5px;
  border: 1px solid #e6e6e6;
  text-align: left;
}
#results-table th {
  font-weight: bold;
}

/*------------------
 * 2. Debug
 *------------------*/

.log:only-child {
  height: inherit;
}
.log {
  background-color: #e6e6e6;
  border: 1px solid #e6e6e6;
  color: black;
  display: block;
  font-family: "Courier New", Courier, monospace;
  height: 230px;
  overflow-y: scroll;
  padding: 5px;
  white-space: pre-wrap;
}
div.screenshot {
  border: 1px solid #e6e6e6;
  float: left;
  margin-left: 5px;
  height: 220px;
}
div.screenshot img {
  height: 220px;
}

/*if the result is passed or xpassed don't show debug row*/
.passed + .debug,
.unexpected.pass + .debug {
  display: none;
}

/*------------------
 * 3. Sorting items
 *------------------*/
.sortable {
  cursor: pointer;
}

.sort-icon {
  font-size: 0;
  float: left;
  margin-right: 5px;
  margin-top: 5px;
  /*triangle*/
  width: 0;
  height: 0;
  border-left: 8px solid transparent;
  border-right: 8px solid transparent;
}

.inactive .sort-icon {
  /*finish triangle*/
  border-top: 8px solid #e6e6e6;
}

.asc.active .sort-icon {
  /*finish triangle*/
  border-bottom: 8px solid #999;
}

.desc.active .sort-icon {
  /*finish triangle*/
  border-top: 8px solid #999;
}
